@@ -30,14 +30,14 @@ class SourceOutput : public Stream
 {
     Q_OBJECT
 public:
-    SourceOutput(QObject *parent);
+    explicit SourceOutput(QObject *parent);
 
     void update(const pa_source_output_info *info);
 
-    void setVolume(qint64 volume) Q_DECL_OVERRIDE;
-    void setMuted(bool muted) Q_DECL_OVERRIDE;
-    void setChannelVolume(int channel, qint64 volume) Q_DECL_OVERRIDE;
-    void setDeviceIndex(quint32 deviceIndex) Q_DECL_OVERRIDE;
+    void setVolume(qint64 volume) override;
+    void setMuted(bool muted) override;
+    void setChannelVolume(int channel, qint64 volume) override;
+    void setDeviceIndex(quint32 deviceIndex) override;
 };
 
 } // QPulseAudio
